@@ -13,7 +13,7 @@ use std::{
 
 const EXCHANGE_NAME: &str = "bybit";
 
-#[test_case(MarketType::InverseFuture, "BTCUSDU21")]
+#[test_case(MarketType::InverseFuture, "BTCUSDZ21")]
 #[test_case(MarketType::InverseSwap, "BTCUSD")]
 #[test_case(MarketType::LinearSwap, "BTCUSDT")]
 fn test_crawl_trade(market_type: MarketType, symbol: &str) {
@@ -26,7 +26,7 @@ fn test_crawl_trade(market_type: MarketType, symbol: &str) {
     )
 }
 
-#[test_case(MarketType::InverseFuture, "BTCUSDU21")]
+#[test_case(MarketType::InverseFuture, "BTCUSDZ21")]
 #[test_case(MarketType::InverseSwap, "BTCUSD")]
 #[test_case(MarketType::LinearSwap, "BTCUSDT")]
 fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
@@ -39,7 +39,7 @@ fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
     )
 }
 
-#[test_case(MarketType::InverseFuture, "BTCUSDU21")]
+#[test_case(MarketType::InverseFuture, "BTCUSDZ21")]
 #[test_case(MarketType::InverseSwap, "BTCUSD")]
 #[test_case(MarketType::LinearSwap, "BTCUSDT")]
 fn test_crawl_l2_snapshot(market_type: MarketType, symbol: &str) {
@@ -52,7 +52,19 @@ fn test_crawl_l2_snapshot(market_type: MarketType, symbol: &str) {
     )
 }
 
-#[test_case(MarketType::InverseFuture, "BTCUSDU21")]
+#[test_case(MarketType::InverseFuture)]
+#[test_case(MarketType::InverseSwap)]
+#[test_case(MarketType::LinearSwap)]
+fn test_crawl_l2_snapshot_without_symbol(market_type: MarketType) {
+    gen_test_snapshot_without_symbol_code!(
+        crawl_l2_snapshot,
+        EXCHANGE_NAME,
+        market_type,
+        MessageType::L2Snapshot
+    )
+}
+
+#[test_case(MarketType::InverseFuture, "BTCUSDZ21")]
 #[test_case(MarketType::InverseSwap, "BTCUSD")]
 #[test_case(MarketType::LinearSwap, "BTCUSDT")]
 fn test_crawl_ticker(market_type: MarketType, symbol: &str) {
